@@ -770,7 +770,16 @@ class MyApp(wx.App):
             self.trace.Append([str(level),msg])
         
     def OnInit(self):
-        global SX
+        global SX, display
+
+        display = os.popen('gconftool-2 -g /system/osso/dsm/display/display_dim_timeout').read()
+        display=int(display)
+
+        if display==2345:
+              display=60
+
+        os.popen('gconftool-2 -s /system/osso/dsm/display/display_dim_timeout -t int '+ str(2345))
+
         self.ThreadControl = 0 #say thread what to do
         self.COMPORT = 0
         self.senprod = None
@@ -1534,8 +1543,12 @@ later version.
 
         
     def OnExit(self,e = None):
+        global display
         import sys
 
+        os.popen('gconftool-2 -s /system/osso/dsm/display/display_dim_timeout -t int '+ str(display))
+        display = os.popen('gconftool-2 -g /system/osso/dsm/display/display_dim_timeout').read()
+
         if self.BToff==True:
             bus = dbus.SystemBus()
             manager = dbus.Interface(bus.get_object("org.bluez", "/"),"org.bluez.Manager")
